//=============================================================================
// aq_class_centeredwindowbuffer.h
//
// 
// 15 Jan 2002 Version 1.0
// 21 Mar 2006 Version 1.1 - 	add explicit windowbuffer<T>:: to method calls, 
//				e.g. windowbuffer<T>::add()
//
// Description:
//
// This class is like a windowbuffer but tries to keep get() objects from the
// middle buffer so that there is the same number of objects are before and 
// after the current get().  When add() returns a non-zero buffer address, an
// object should be loaded in that address. 
//
//
// template<class T>
// class circlewindowbuffer : public stackbuffer<T>
// {
// public:
//     windowbuffer( size_t size ) : stackbuffer<T>( size )
//     T* add()		// points to buffer to load object
//     T* get()		// points to buffer to get object. 0 if buf not loaded.
//     T* next()		// next object that will be read. Zero if at end.
//     T* last()		// last object that was read. Zero =if at beginning.
//
// 			// look in any object.
//     T* peek ( size_t index ) {return stackbuffer<T>::get( index );}
//
// 			// index of next buffer to get.
// 		        // range is 0 to size()-1, -1 at end.
//     int    index( ) const {return windex<length() ? windex : -1;}
//
//     bool   atbeg( ) const {return windex == 0;}		// at start of window
//     bool   atend( ) const {return windex >= length();}	// next get will fail
//     void   clear( ) { windex = 0; stackbuffer<T>::clear(); }
//
//     bool   full()    const;
//     bool   addflag() const;		// need to add object to buffer
//     size_t length()  const;		// number of objects in buffer
//     size_t size()    const;		// max no. of objects allowed
//
//     virtual ~windowbuffer( ) {}
// };
//
//
// ostream& operator<<( ostream& os, windowbuffer<T>& buf )
//
//=============================================================================
//page


#if !defined(AQ_CLASS_CENTEREDWINDOWBUFFER)
#define      AQ_CLASS_CENTEREDWINDOWBUFFER

#include "aq_class_windowbuffer.h"


template<class T>
class centeredwindowbuffer : public windowbuffer<T>
{
    size_t tgt;
 
public:

    explicit centeredwindowbuffer( size_t size ) : windowbuffer<T>(size), tgt(size/2)
    {  }

    T* add() 
    { 
	if( addflag() ) return windowbuffer<T>::add();
	return 0;
    }

    bool addflag() const
    {
	return !windowbuffer<T>::full() || (windowbuffer<T>::index() > tgt);
    }

    virtual ~centeredwindowbuffer() {}
};


//-----------------------------------------------------------------------------
// operator<<
//	diagnostic print
//-----------------------------------------------------------------------------

template<class T>
static ostream& operator<<( ostream& os, const centeredwindowbuffer<T>& buf )
{
    os<<(windowbuffer<T>&)buf<<endl;
    return os;
}

#endif


