//==============================================================================
// aq_class_configurationlist.c
//
// 
// 01 Jun 2001 Version 1.0
// 28 May 2002         1.1 - add <assert.h>, <iostream>
//
// This class contains a list of keyword and value pairs. 
// Keywords must first be defined once and only once. 
//
//==============================================================================

#include "aq_class_configurationlist.h"
#include <assert.h>
#include <iostream>


//------------------------------------------------------------------------------
// Define  keyword-value
//
//------------------------------------------------------------------------------

void 
configuration_list::define(cstring& keyword, cstring defaultValue)
{
    assert( find(keyword)==end() );	// duplicate key error
    (*this)[keyword] = defaultValue;   
}


//------------------------------------------------------------------------------
// Set value
//
//------------------------------------------------------------------------------

bool configuration_list::setvalue( cstring& keyword, cstring& value )
{
    if( find(keyword) == end() ) return false;  // false= key not found
    (*this)[keyword] = value;

    return true;				// true = success
}


//------------------------------------------------------------------------------
// Get value
//
//------------------------------------------------------------------------------

string configuration_list::getvalue( cstring& keyword ) const
{
    assert( find(keyword) != end() );
    return  (*find(keyword)).second;
}


//------------------------------------------------------------------------------
// begin iterator
//
//------------------------------------------------------------------------------

cfg_iterator configuration_list::begin() const
{
    return cfg_map::begin();
}


//------------------------------------------------------------------------------
// end iterator
//
//------------------------------------------------------------------------------

cfg_iterator configuration_list::end() const
{
    return cfg_map::end();
}



//------------------------------------------------------------------------------
// Print
//
//------------------------------------------------------------------------------

ostream& operator<<( ostream& os, const configuration_list& list  )
{
    for(cfg_iterator  ptr=list.begin(); ptr!=list.end(); ptr++)
        os<<ptr->first<<'\t'<<'\t'<<ptr->second<<endl;

    return os;
}

