//==============================================================================
// aq_class_gbadpacket.h
//
// 
// 17 May 2001 Version 1.0
// 27 Oct 2003 Version 1.2 - allow APID to change
//
// Purpose:
//     This class defines Aqua CCDS Ground Based Attitude Determination Data 
//     (GBAD) Packet APID 957. These are input packets to program. 
//
// Note:
//	See EOS PM-1 Spacecraft to EOS Ground Systems ICD, GSFC 422-11-19-03.
//
//      ItemList contains the following entries:
//	p[ 0] - p[ 2] 	position
//	p[ 3] - p[ 5] 	velocity
//	p[ 6] - p[ 9] 	attitude
//	p[10] - p[12]   attitude rate
//
//	Time returned is TAI Julian Date from 01 Jan 1953 at 0 hr =   
//	2436203.5. See CCSDS Recommendation for Time Code Formats
//
//	See Theoretical Basis of the SDP Toolkit Geolocation Package for the
//	ECS Project, 445-TP-002-002, May 1995,  Section 4.8.1
//
//
//==============================================================================

#if !defined( AQ_CLASS_GBADPACKET)
#define       AQ_CLASS_GBADPACKET

#include <vector>
#include "aq_typdef_header.h"
#include "aq_class_packet.h"


//page
//------------------------------------------------------------------------------
// GBAD packet
//
//------------------------------------------------------------------------------

class gbadpacket : public packet
{
    array  p;
    double time;

public:
    gbadpacket();

    virtual
    istream& ReadPkt(istream& is);

    double      TimeTag()  const;	// TAI Julian Days since 01 Jan 1958
    gbadpacket& TimeTag( double time );

    size_t  CoarseTime() const;		// TAI seconds for diagnostics only
    size_t  FineTime()   const;		// fraction of sec diagnostics

    carray Position() const;
    carray Velocity() const;
    carray Attitude() const;
    carray AngleRates() const;
 
    array&  ItemList();
    carray& ItemList() const;

    static size_t pktsize;
    static size_t apid;
};

ostream& operator<<( ostream& os, const gbadpacket& pkt);


#endif


















