//=============================================================================
// aq_class_gbadpktprocessor.c
//
// 
// 23 Nov 2001 Version 1.0
//
// Purpose:
// 	Implement operations which must span entire pass, e.g. record count, or
//	list of orbits. Quality Flags and ephemeris or attitude repair should go 
//	here if implemented. 
//
// Note:
//	"ReadPkt" may, if ephemeris repair code is installed, not actually read
//	from input file; it is only required to process the next packet.
//
//	"class buildorbitlist" builds and maintains list of orbits.
//
//	statistical items are only valid after entire packet file has been read.
//
//=============================================================================


#include "aq_class_gbadpktprocessor.h"



//-----------------------------------------------------------------------------
// Constructor
//
//-----------------------------------------------------------------------------

gbadpktprocessor::gbadpktprocessor( packetfile& _pktfile )
: repairstream( _pktfile), pfile(_pktfile)
{
    recordcnt = 0;
}


//-----------------------------------------------------------------------------
// ReadPkt
//
//	Process a new packet.
//-----------------------------------------------------------------------------

gbadpacket* gbadpktprocessor::ReadPkt( )
{
    gbadpacket* packet = repairstream.getfixedpkt();
    if( !packet ) return 0;

    qflags = repairstream.getQualityFlags();

					// Check if this pkt starts new orbit
					// which must be added to list. 
    bool neworbit = orbitList.checkpacket( *packet );	
	
	//debug
//	if( neworbit ) cout<<"new orbit packet = "<<(*packet)<<endl;
	
	
    recordcnt++;			// this may have to be modified

    return packet;
}


//page
//-----------------------------------------------------------------------------
// RecordCount
//
//	Number of output packets
//-----------------------------------------------------------------------------

size_t  gbadpktprocessor::RecordCount( ) const
{
    return recordcnt;
}


//-----------------------------------------------------------------------------
// GetOrbitList
//
//	Get list of Orbits in Pass. Orbit is defined by "orbitstuff" structure.
//-----------------------------------------------------------------------------

const vector<orbitstuff>& gbadpktprocessor::GetOrbitList() const
{
    return orbitList.getorbitlist();
}


//-----------------------------------------------------------------------------
// QualityFlags
//
//-----------------------------------------------------------------------------

quality_flags  gbadpktprocessor::QualityFlags() const { return qflags;}  


//-----------------------------------------------------------------------------
// packetfile
//
//-----------------------------------------------------------------------------

packetfile& gbadpktprocessor::PacketFile() { return pfile; }


//-----------------------------------------------------------------------------
// getLastPktRead
//		- last packet read from file
//-----------------------------------------------------------------------------

const gbadpacket* gbadpktprocessor::getLastPktRead()
{
    return repairstream.getLastPktRead();
}



