//=============================================================================
// aq_class_gbadpktprocessor.h
//
// 
// 23 Nov 2001 Version 1.0
//
// Purpose:
// 	Implement operations which must span entire pass, e.g. record count, or
//	list of orbits. Quality Flags and ephemeris or attitude repair should go 
//	here if implemented. 
//
// Note:
//	"ReadPkt" may, if ephemeris repair code is installed, not actually read
//	from input file; it is only required to process the next packet.
//
//	"class buildorbitlist" builds and maintains list of orbits.
//
//	statistical items are only valid after entire packet file has been read.
//
//=============================================================================



#if !defined(AQ_CLASS_GBADPKTPROCESSOR)
#define      AQ_CLASS_GBADPKTPROCESSOR

#include "aq_class_packetfile.h"
#include "aq_typdef_header.h"
#include "aq_class_gbadpacket.h"
#include "aq_class_orbitstuff.h"
#include "aq_class_buildorbitlist.h"
#include "aq_class_repairpktstream.h"
#include "aq_class_qualityflags.h"


class gbadpktprocessor
{
    repairpktstream repairstream;
    buildorbitlist  orbitList;
    size_t          recordcnt ;
    quality_flags   qflags;
    packetfile     &pfile ;

public:
    gbadpktprocessor( packetfile& _pktfile );
    gbadpacket* ReadPkt( );				// process next packet
    size_t RecordCount( ) const;			// records processed
    const vector<orbitstuff>& GetOrbitList() const;	// list of orbits spanned
    quality_flags  QualityFlags() const;
    packetfile& PacketFile();
    const gbadpacket* getLastPktRead();			// last pkt read from file
};


#endif




