//==============================================================================
// aq_class_nevilleinterpolater.h
//
// 
// 13 Jun 2001 Version 1.0
//
// Neville's recursive interpolater.
//
// from pairs 
//	  (X1,Y1)....(X4,Y4),
//
// construct:
//
//        x(1):   y(1) = P[1:1]
//                                P[1:2]
//        x(2):   y(2) = P[2:2]           P[1:3]
//                                P[2:3]          P[1:4]
//        x(3):   y(3) = P[3:3]           P[2:4]
//                                P[3:4]
//        x(3):   y(4) = P[4:4]
//
// from:
//                 (x(j) - x)*P[i:j-1] + (x - x(i))*P[i+1:j]
//      P[i:j] = -----------------------------------------
//                            x(j) - x(i)
// 
// starting with P(1,4).
//
//
// In the code below, "xylist" is a list of xy pairs. The xylist optionally be
// specified in the constructor or with the "setxylist member function. The list 
// need not be evenly spaced along x. 
//
//==============================================================================


#if !defined(AQ_CLASS_NEVILLEINTERP)
#define      AQ_CLASS_NEVILLEINTERP

#include <stddef.h>
#include <vector>
#include <utility>
 using namespace std;

typedef pair<double,double> dblpair;  	// pair<x,y>
typedef vector<dblpair>     dblplist;   // array of pairs of doubles



class nevilleinterpolater
{
    const    dblplist*  xy;   
    mutable  double x;
    double   P(size_t i, size_t j ) const;

public:
    nevilleinterpolater( const dblplist* xylistPtr = 0);
    nevilleinterpolater& setxylist( const dblplist* xylistPtr );

    double interpolate( double xvalue ) const;		// get interpolated y
};



#endif

