//==============================================================================
// aq_class_satpasses.h
//
// 
// 18 May 2001 Version 1.0
// 08 Aug 2003 Version 1.1 - correct meanMo units
//
// Object to get orbital parameters from pass packets and NORAD two line elements
//
//==============================================================================


#if !defined(AQ_CLASS_SATPASSES)
#define      AQ_CLASS_SATPASSES

#include <iostream>
#include "aq_class_orbitstuff.h"
#include "orbitlib_class_NoradElements.h"
#include "aq_typdef_header.h"


class satpasses
{
    double begTime;		// pass start (JD)
    double endTime;		// pass stop  (JD)
    double ascTime;		// Ascending  Node Time (JD)
    double dscTime;		// Descending Node Time (JD)
    size_t epochRev ;		// Revolution number from TLE
    double epochTime;		// Julian Date of Norad TLE
    double epochAscTime;	// Julian Date of Asc Node time near epoch
    double meanMo; 		// mean motion, rad/day
    double wPlusM_Ep;		// angle from asc. node at Epoch (rad)
    double wPlusM_Ps;		// angle from asc. node pass start (rad)
    double rightAsc ;		// right ascension
    double TAIminusUTC;		//

    array  begKepler;		// kepler elements at  pass start

public:
    satpasses( const noradelements& noradtle  );
    satpasses& SetOrbit( const orbitstuff& orbit );

    array   BegKepler()      const;
    double  EpochTimeTAI93() const;		// seconds
			
    size_t  BegOrbitRev()  const;
    size_t  EndOrbitRev()  const;

    double  BegOrbitTime() const;		// JD
    double  EndOrbitTime() const;		// JD

    double  AscendingNodeTime()  const;		// JD
    double  DescendingNodeTime() const;		// JD
    double  DescendingNodeLongitude()  const;	// Radians

    void    print_state( ostream& os = cout );	// diagnostic
};

    ostream& operator<<( ostream& os, const satpasses& satpass );

#endif








