//==============================================================================
// aq_class_storebase.c
//
// 
// 17 May 2001 Version 1.0
//
// This is intended as a base class providing storage for packets and records
//
// size is total packet size = header + time + data 
//
//==============================================================================

#include "aq_class_storebase.h"
#include <iostream>
#include <stdlib.h>
#include <stdio.h>
#include <cstring>

//------------------------------------------------------------------------------
// Constructors
//
//------------------------------------------------------------------------------

storebase::storebase( size_t _size)   // size is total packet size
{
    dataPtr = new char[size = _size];
    memset( dataPtr, 0, size);
    usecnt = 0;
}


storebase::storebase( const storebase& base)
{
    dataPtr = new char[ size = base.DataSize() ];
    memcpy( dataPtr, base.DataPtr(), size);
    usecnt = 0;
}


//------------------------------------------------------------------------------
// DataPointer
//
//------------------------------------------------------------------------------

char* storebase::DataPtr() const
{
    return dataPtr;
}


//page
//------------------------------------------------------------------------------
// DataSize
//
//------------------------------------------------------------------------------

size_t storebase::DataSize() const
{
    return size;
}


//------------------------------------------------------------------------------
// Clear
//
//------------------------------------------------------------------------------

void storebase::Clear(int v)
{
    memset( dataPtr, v, size);
}


//------------------------------------------------------------------------------
// Lock and Unlock
//
//------------------------------------------------------------------------------

void storebase::lock() const
{
    usecnt++;
}


void storebase::unlock() const
{
    usecnt--;
}


int  storebase::getlock() const
{
    return usecnt;
}


//page
//------------------------------------------------------------------------------
// operator=
//
//------------------------------------------------------------------------------

storebase& storebase::operator=( const storebase& base)
{
    if( dataPtr == base.DataPtr() ) return *this;
    delete [] dataPtr;

    dataPtr = new char[ size = base.DataSize() ];
    memcpy( dataPtr, base.DataPtr(), size);

    return *this;
}


//------------------------------------------------------------------------------
// Destructor
//
//------------------------------------------------------------------------------

storebase::~storebase()
{
    delete [] dataPtr;

    if( usecnt)
    {
	cerr<<"Program error: storebase use count = "<<usecnt<<endl;
	exit(-1);
    }
}
 

