//==============================================================================
// aq_proc_euleranglesinorbitalframe.c
//
// 
// 09 Nov 2001 Version 1.0
// 26 Jun 2002         1.1 - change Euler Selection
//
// Purpose:
//	Compute Euler Angles in Orbital Coordinates.
//
// Method:
//	Compute rotation from inertial to orbital coordinates (Aio) from 
//	position and velocity. 
//
//	Compute rotation from spacecraft to inertial coordinates from quaternion.
//
//	Assume small angle approximation; euler angles are off-diagonal elements.
// 
// NOTE:
//	 
//
//==============================================================================

#include "aq_proc_euleranglesinorbitalframe.h"
#include "orbitlib_proc_InertialToOrbitalMtx.h"
#include "orbitlib_proc_QuaternionToAttitudeMtx.h"
#include "mathlib_class_Matrix.h"

#include <iomanip>

carray  EulerAnglesInOrbitalFrame( const gbadpacket& pkt )
{
	matrix Aio = InertialToOrbitalMtx(    pkt.Position(), pkt.Velocity() );
	matrix Asi = QuaternionToAttitudeMtx( pkt.Attitude() );
	matrix Aos = Asi * Aio++;

	array  angles(3);
	angles[0] = Aos(1,2);
	
//      angles[1] = Aos(1,3);  before 26 June 2002
//      angles[2] = Aos(2,3);  before 26 June 2002

	angles[1] = Aos(2,3);
	angles[2] = Aos(3,1);

/*
	cout.precision(8);
	cout.setf(ios::fixed |ios::showpos );

	cout<<"\nAio = "<<Aio<<endl;
	cout<<"\nAsi = "<<Asi<<endl;
	cout<<"\nAso = "<<Aos<<endl;
	exit(-2);
*/

	return angles;
}







