//==============================================================================
// aq_proc_formatconvert_x.c
//
// 
// 06 Jun 2001 Version 1.0
// 18 Nov 2003 Version 1.1 - add signed char to int conversion
// 23 Mar 2006 Version 1.2 - fix Format_convert_long4,ulong4 for 640bit machines.
//
// machine-dependent conversions from byte-string to internal format
//
//==============================================================================

#include <string.h>
#include "aq_proc_formatconvert_x.h"
#include <iostream>


//------------------------------------------------------------------------
// convert from byte-string to internal format of type
//
//------------------------------------------------------------------------

#if defined(MACHINE_IS_SGI)	// bigendian IEEE format

int FormatConvert_schar( const char* ptr )
{
		return (int)*(signed char*)(ptr);
}

unsigned short  FormatConvert_ushort2( const char* ptr )
{
        unsigned short  t = 0;
        return *(unsigned short*)memcpy(&t, ptr, 2);
}

unsigned long   FormatConvert_ulong4( const char* ptr )
{
	unsigned long t = 0;
        return *(unsigned long*)memcpy(&t, ptr, 4);
}


//page
short  FormatConvert_short2( char a, char b )
{
        short s = 0;
	*(char*)&s = a;
	*((char*)&s + 1) = b;

	return s;
}

short  FormatConvert_short2( const char* ptr )
{
	short  t = 0;
	return *(short*)memcpy(&t, ptr, 2);
}

long   FormatConvert_long4( const char* ptr )
{
	long   t = 0;
	return *(long*)memcpy(&t, ptr, 4);
}

float  FormatConvert_float4( const char* ptr )
{
	float  t = 0.0;	
	return *(float*)memcpy(&t, ptr, 4);
}


double  FormatConvert_float6( const char* ptr )
{
	double  t = 0.0;
	return  *(double*)memcpy( &t, ptr, 6);
}

double  FormatConvert_float8( const char* ptr )
{
	double  t = 0.0;
	return  *(double*)memcpy( &t, ptr, 8);
}
#endif


//page
//------------------------------------------------------------------------
// convert from internal type to byte-string
//
//------------------------------------------------------------------------

#if defined(MACHINE_IS_SGI)	// bigendian IEEE format

void FormatConvert_short2( short v, char* ptr )
{
    memcpy( ptr, &v, 2 );
}


void FormatConvert_long4( size_t v, char* ptr )
{
    memcpy( ptr, &v, 4 );
}


void FormatConvert_float4( float v, char* ptr )
{
    memcpy( ptr, &v, 4 );
}

void FormatConvert_float8( double v, char* ptr )
{
    memcpy( ptr, &v, 8 );
}

#endif


//page
//------------------------------------------------------------------------
// convert from byte-string to internal format of type
//
//------------------------------------------------------------------------

#if defined(MACHINE_IS_INTEL)	// little endian IEEE format

static void swap(void* t, const void* s, size_t siz)
{
    for( size_t k=0; k<siz; k++) 
	*((char*)t + k) = *((char*)s + siz-1-k);
}


int FormatConvert_schar( const char* ptr )
{
		return (int)*(signed char*)(ptr);
}


unsigned short  FormatConvert_ushort2( const char* ptr )
{
        unsigned short t = 0;
	swap( &t, ptr, 2 );
        return t;
}

unsigned long   FormatConvert_ulong4( const char* ptr )
{
	unsigned long  t = 0;
	swap( &t, ptr, 4 );
        return t;
}

short  FormatConvert_short2( char a, char b )
{
        short s = 0;
	*(char*)&s = b;
	*((char*)&s + 1) = a;
	return s;
}

short  FormatConvert_short2( const char* ptr )
{
	short  t = 0;
	swap( &t, ptr, 2);
	return t;
}


//page
//
long   FormatConvert_long4( const char* ptr )
{
	long t;
	int(*ptr) < 0 ?  t=-1 : t=0;
	swap( &t, ptr, 4);

	return t;
}

float  FormatConvert_float4( const char* ptr )
{
	float  t = 0.0;
	swap( &t, ptr, 4);	
	return t;
}


double  FormatConvert_float6( const char* ptr )
{
	double  t = 0.0;
	swap(  &t, ptr, 6);
	return  t;
}

double  FormatConvert_float8( const char* ptr )
{
	double  t = 0.0;
	swap(  &t, ptr, 8);
	return  t;
}
#endif


//page
//------------------------------------------------------------------------
// convert from internal type to byte-string
//
//------------------------------------------------------------------------

#if defined(MACHINE_IS_INTEL)	// little endian IEEE format


void FormatConvert_short2( short v, char* ptr )
{
    swap( ptr, &v, 2 );
}


void FormatConvert_long4( size_t v, char* ptr )
{
    swap (ptr, &v, 4 );
}


void FormatConvert_float4( float v, char* ptr )
{
    swap( ptr, &v, 4 );
}


void FormatConvert_float8( double v, char* ptr )
{
    swap( ptr, &v, 8 );
}

#endif


