//------------------------------------------------------------------------------
//
// constlib_TimeConstants.h - commonly used constants
//
// 05 Oct 1999 Version 1.0
//
// Notes:
//
// 1. Theoretical Basis of SDP Toolkit, 445-TP-002-002
// 2. CCSDS Recommendation for Time Code Formats
// 3. Astronomical Algorithms, Meeus
// 4. Explanatory Supplement to the Astronomical Almanac
// 5. Goddard Trajectory Determination System (GTDS) Mathematical Theory Rev. 1
//
//------------------------------------------------------------------------------


#if  !defined(CONSTLIB_TIME_CONSTANTS)
#define CONSTLIB_TIME_CONSTANTS

    const long double 			
        time_const_JD0000 = 0.0L,       // 01 January 4713 BC noon, Note 4,pg.55
					// = -4712 January 1 noon proleptic cal., 
					// Note 4, section 12.7,12.8
					// = year -4712 January 1.5

					// Julian Date of start year 2000
					// Note 1, page 4-19
        time_const_JD2000 = 2451545.0L, 

        time_const_JD1970 = 2440587.5L, // Julian Date of unix second = 0
                                        // calender date: Jan 1 1970 00:00:00

					// Max value of a long word
					// 19 Jan 2038 03:14:07
					// 2147483647 seconds since 1970
	time_const_JDMaxUnixTime = 2465442.63480324L,

					// Modified Julian Date, 17 Nov 1858 at
					// 0h UT. Note 3, page 63
        time_const_ModifiedJulianDate = 2400000.5L,

 					// sideral days, Note 3, page 83
	time_const_MeanSolarDay = 1.00273790935,

					// TAI Julian time zero, 01 Jan 1958 0 hr
					// Note 2,  page B-5
					// Note 5,  section 3.5.1
	time_const_01Jan1958_TAI = 2436204.5,

					// Satellite Toolkit epoch. Note 1,
					// Section 4.8.1   Julian Days.
	time_const_01Jan1993_SDP = 2448988.5003125,

					// Days in a Julian Century. 
					// Note 1, page 4-18
	time_const_JDCentury_days= 36525,

					// Terrestrial - TAI time, Note 1, 
					// page 4-6
	time_const_TDT_minus_TAI = 32.184
    ;

#endif




