//------------------------------------------------------------------------------
// orbitlib_proc_ConvertRectangularToKepler.h
//
//      29 Feb 2000 Version 1.0
//
//      InertialRectToKepler computes keplerian elements from geocentric 
//      inertial rectangular elements. The implementation follows "Brouwer-
//      Lyaddane Orbit Generator Routine", X-553-70-223, E. A. Galbreath, 
//      June 1970.
//
//
//      input: 
//
//	V[0] = x  	(meters)
//	V[1] = y 	(meters)
//	V[2] = z	(meters)
//	V[3] = xdot 	(meters/sec)
//	V[4] = ydot 	(meters/sec)
//	V[5] = zdot 	(meters/sec)
//
//      returns:
//
//	V[0] = A	semi major axis	  (meters)
//      V[1] = e	eccentricity
//      V[2] = i	incliniation	  (radians)
//      V[3] = N	Ascending Node    (radians)
//      V[4] = w	Angle of Perigee  (radians)
//      V[5] = m 	Mean Anomaly	  (radians)
//
//------------------------------------------------------------------------------

#if !defined(ORBITLIB_CONVERTRECTANGULARTOKEPLER)
#define      ORBITLIB_CONVERTRECTANGULARTOKEPLER

#include <vector>
 using namespace std;

vector<double>  Convert_RectangularToKepler (const vector<double>& V);

#endif
